==> dcl_0.9.2.orig.tar.gz: dcl/inc/class.htmlChklstTpl.inc.php <==
<?php
/*
 * $Id: class.htmlChklstTpl.inc.php,v 1.1.1.1.2.1 2002/02/15 07:06:27 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

//LoadStringResource('chklst');

class htmlChklstTpl
{
	function show()
	{
	}

	function add()
	{
		global $dcl_info;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$t = CreateTemplate(array('hForm' => 'htmlChklstTplAdd.tpl'));
		$t->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
		$t->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
		$t->set_var('VAL_FORMACTION', menuLink());
		$t->set_var('VAL_MENUACTION', 'boChecklistTpl.dbadd');
		$t->set_var('TXT_TITLE', 'Upload Checklist Template');
		$t->set_var('TXT_FILE', 'File');
		$t->set_var('VAL_MAXUPLOADFILESIZE', $dcl_info['DCL_MAX_UPLOAD_FILE_SIZE']);
		$t->set_var('CMB_ACTIVE', GetYesNoCombo('Y', 'dcl_chklst_tpl_active', 0, false));
		$t->set_var('TXT_ACTIVE', STR_CMMN_ACTIVE);
		$t->set_var('VAL_NAME', STR_CMMN_NEW);
		$t->set_var('BTN_SAVE', STR_CMMN_SAVE);
		$t->set_var('BTN_RESET', STR_CMMN_RESET);

		$t->pparse('out', 'hForm');
	}

	function modify()
	{
		global $dcl_info;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$o = CreateObject('dcl.dbChklstTpl');
		$o->Load($GLOBALS['dcl_chklst_tpl_id']);

		$t = CreateTemplate(array('hForm' => 'htmlChklstTplAdd.tpl'));
		$t->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
		$t->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
		$t->set_var('VAL_FORMACTION', menuLink());
		$t->set_var('VAL_MENUACTION', 'boChecklistTpl.dbmodify');
		$t->set_var('VAL_ID', $GLOBALS['dcl_chklst_tpl_id']);
		$t->set_var('TXT_TITLE', 'Modify Checklist Template');
		$t->set_var('TXT_FILE', 'File');
		$t->set_var('VAL_MAXUPLOADFILESIZE', $dcl_info['DCL_MAX_UPLOAD_FILE_SIZE']);
		$t->set_var('CMB_ACTIVE', GetYesNoCombo($o->dcl_chklst_tpl_active, 'dcl_chklst_tpl_active', 0, false));
		$t->set_var('TXT_ACTIVE', STR_CMMN_ACTIVE);
		$t->set_var('VAL_NAME', $o->dcl_chklst_tpl_name);
		$t->set_var('BTN_SAVE', STR_CMMN_SAVE);
		$t->set_var('BTN_RESET', STR_CMMN_RESET);

		$t->pparse('out', 'hForm');
	}

	function delete()
	{
	}

	function view()
	{
	}
}
?>

==> dcl_0.9.4.4.orig.tar.gz: dcl/inc/class.htmlChklstTpl.inc.php <==
<?php
/*
 * $Id: class.htmlChklstTpl.inc.php,v 1.1.1.1.2.1.2.1 2003/11/11 05:50:04 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

//LoadStringResource('chklst');

class htmlChklstTpl
{
	function show()
	{
	}

	function add()
	{
		global $dcl_info;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$t = CreateTemplate(array('hForm' => 'htmlChklstTplAdd.tpl'));
		$t->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
		$t->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
		$t->set_var('VAL_FORMACTION', menuLink());
		$t->set_var('VAL_MENUACTION', 'boChecklistTpl.dbadd');
		$t->set_var('TXT_TITLE', 'Upload Checklist Template');
		$t->set_var('TXT_FILE', 'File');
		$t->set_var('VAL_MAXUPLOADFILESIZE', $dcl_info['DCL_MAX_UPLOAD_FILE_SIZE']);
		$t->set_var('CMB_ACTIVE', GetYesNoCombo('Y', 'dcl_chklst_tpl_active', 0, false));
		$t->set_var('TXT_ACTIVE', STR_CMMN_ACTIVE);
		$t->set_var('VAL_NAME', STR_CMMN_NEW);
		$t->set_var('BTN_SAVE', STR_CMMN_SAVE);
		$t->set_var('BTN_RESET', STR_CMMN_RESET);
		$t->set_var('BTN_CANCEL', STR_CMMN_CANCEL);
		$t->set_var('LNK_CANCEL', menuLink('', 'menuAction=boChecklistTpl.show'));

		$t->pparse('out', 'hForm');
	}

	function modify()
	{
		global $dcl_info;

		if (!$GLOBALS['g_oSec']->HasSecLvl($GLOBALS['dcl_info']['DCL_ADD_USER']))
			return PrintPermissionDenied();

		$o = CreateObject('dcl.dbChklstTpl');
		$o->Load($GLOBALS['dcl_chklst_tpl_id']);

		$t = CreateTemplate(array('hForm' => 'htmlChklstTplAdd.tpl'));
		$t->set_var('COLOR_DARK', $dcl_info['DCL_COLOR_DARK']);
		$t->set_var('COLOR_LIGHT', $dcl_info['DCL_COLOR_LIGHT']);
		$t->set_var('VAL_FORMACTION', menuLink());
		$t->set_var('VAL_MENUACTION', 'boChecklistTpl.dbmodify');
		$t->set_var('VAL_ID', $GLOBALS['dcl_chklst_tpl_id']);
		$t->set_var('TXT_TITLE', 'Modify Checklist Template');
		$t->set_var('TXT_FILE', 'File');
		$t->set_var('VAL_MAXUPLOADFILESIZE', $dcl_info['DCL_MAX_UPLOAD_FILE_SIZE']);
		$t->set_var('CMB_ACTIVE', GetYesNoCombo($o->dcl_chklst_tpl_active, 'dcl_chklst_tpl_active', 0, false));
		$t->set_var('TXT_ACTIVE', STR_CMMN_ACTIVE);
		$t->set_var('VAL_NAME', $o->dcl_chklst_tpl_name);
		$t->set_var('BTN_SAVE', STR_CMMN_SAVE);
		$t->set_var('BTN_RESET', STR_CMMN_RESET);
		$t->set_var('BTN_CANCEL', STR_CMMN_CANCEL);
		$t->set_var('LNK_CANCEL', menuLink('', 'menuAction=boChecklistTpl.show'));

		$t->pparse('out', 'hForm');
	}

	function delete()
	{
	}

	function view()
	{
	}
}
?>
